==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/gotolinedialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "gotolinedialog.h"

#include <qlabel.h>
#include <qlayout.h>

#include <klocale.h>
#include <knuminput.h>


using namespace SubtitleComposer;

GotoLineDialog::GotoLineDialog( int line, int linesCount, QWidget* parent ):
	KDialogBase( parent, 0, true, i18n( "Go to Line" ), KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok )
{
	QWidget* mainWidget = new QWidget( this );
	setMainWidget( mainWidget );

	QVBoxLayout* mainLayout = new QVBoxLayout( mainWidget, 0, spacingHint() );
	mainLayout->addSpacing( spacingHint() ); // A little bit extra space
	mainLayout->addStretch( 10 );

	QLabel* label = new QLabel( mainWidget, i18n( "&Go to line:" ), mainWidget );
	mainLayout->addWidget( label );

	lineNumInput = new KIntNumInput( line, mainWidget );
	lineNumInput->setRange( 1, linesCount );
	lineNumInput->setEditFocus( true );
	lineNumInput->setFocus();
	mainLayout->addWidget( lineNumInput );
}

int GotoLineDialog::lineNumber()
{
	return lineNumInput->value();
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/gotolinedialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "gotolinedialog.h"

#include <qlabel.h>
#include <qlayout.h>

#include <klocale.h>
#include <knuminput.h>


using namespace SubtitleComposer;

GotoLineDialog::GotoLineDialog( int line, int linesCount, QWidget* parent ):
	KDialogBase( parent, 0, true, i18n( "Go to Line" ), KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok )
{
	QWidget* mainWidget = new QWidget( this );
	setMainWidget( mainWidget );

	QVBoxLayout* mainLayout = new QVBoxLayout( mainWidget, 0, spacingHint() );
	mainLayout->addSpacing( spacingHint() ); // A little bit extra space
	mainLayout->addStretch( 10 );

	QLabel* label = new QLabel( mainWidget, i18n( "&Go to line:" ), mainWidget );
	mainLayout->addWidget( label );

	lineNumInput = new KIntNumInput( line, mainWidget );
	lineNumInput->setRange( 1, linesCount );
	lineNumInput->setEditFocus( true );
	lineNumInput->setFocus();
	mainLayout->addWidget( lineNumInput );
}

int GotoLineDialog::lineNumber() const
{
	return lineNumInput->value();
}
